package freemarker.ext.beans;

/*
Copyright 1999 by Scriptum, Inc.,
Mlyva utca 34, H-6771 Szeged, Hungary
All rights reserved.

This software is the confidential and proprietary information
of Scriptum, Inc. ("Confidential Information").  You
shall not disclose such Confidential Information and shall use
it only in accordance with the terms of the license agreement
you entered into with Scriptum.
*/

import freemarker.template.*;
import java.util.*;

/**
 * A wrapper for an arbitrary map that will expose it as a {@link TemplateModelRoot}.
 * All values returned from the {@link #get(java.lang.String)} method are automatically
 * passed through {@link BeansWrapper#wrap(java.lang.Object)}.
 *
 * @author Attila Szegedi, Scriptum Inc.
 * @version $Id: RootMapModel.java,v 1.3 2002/05/11 10:20:30 run2000 Exp $
 */
public class RootMapModel implements TemplateModelRoot {
	private Map map;
	
	/**
	 * Creates a new model with its own internal map.
	 */
	public RootMapModel()
	{
		map = new HashMap();	
	}
	
	/**
	 * Creates a new model that adds {@link TemplateModelRoot} behavior to the
	 * passed map.
	 */
	public RootMapModel(Map map)
	{
		this.map = map;
	}
	
	/**
	 * Returns <code>map.isEmpty()</code> where <code>map</code> is the underlying map.
	 */
	public boolean isEmpty()
	{
		return map.isEmpty();
	}
	
	/**
	 * Returns <code>BeansWrapper.wrap(map.get(key))</code>
     * where <code>map</code> is the underlying Map.
	 */
	public TemplateModel get(String key)
	{
		return BeansWrapper.wrap(map.get(key));
	}
	
	/**
	 * Puts the specified template model into the map.
	 */
	public void put(String key, TemplateModel model)
	{
		map.put(key, model);
	}
	
	/**
	 * Removes the template model with the specified key from the map.
	 */
	public void remove(String key)
	{
		map.remove(key);
	}
}
