/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.ext.jdom;

import freemarker.template.TemplateIteratorModel;
import freemarker.template.TemplateModel;
import freemarker.template.TemplateModelException;

import java.util.Iterator;
import java.util.Map;
import java.util.List;

/**
 * Iterator model for {@link NodeListModel}. This implements a thread-safe
 * iterator over JDOM lists.
 *
 * @version $Id: NodeListIterator.java,v 1.3 2003/11/03 03:33:31 run2000 Exp $
 * @since 1.8
 */
public class NodeListIterator implements TemplateIteratorModel {
    private Iterator nodeIterator;
    private Map namespaces;

    /**
     * Constructor for iterating over a list of nodes.
     *
     * @param nodes the node list to iterate over
     * @param namespaces the registered namespaces for these nodes
     */
    NodeListIterator(List nodes, Map namespaces) {
        if( nodes != null ) {
            this.nodeIterator = nodes.iterator();
        }
        this.namespaces = namespaces;
    }

    /**
     * Returns true if nodes can be returned by a call to {@link #next()}.
     */
    public boolean hasNext() {
        if(nodeIterator == null)
            return false;

        boolean hasNext = nodeIterator.hasNext();
        if(!hasNext)
            nodeIterator = null;
        return hasNext;
    }

    /**
     * Returns the next node.
     */
    public TemplateModel next() {
        return new NodeListModel(nodeIterator.next(), namespaces);
    }

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return nodeIterator == null;
    }
}
