/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.ext.misc;

import freemarker.template.*;

import java.util.List;

/**
 * <p>Iterator for the {@link ExtendedList} class. The most notable addition for
 * this iterator is that ability to determine whether we're at the end
 * of the list. This is done by implementing the
 * {@link freemarker.template.TemplateHashModel} interface as well as the
 * standard {@link freemarker.template.TemplateIteratorModel} interface.</p>
 *
 * @author Nicholas Cull
 * @version $Id: ExtendedIterator.java,v 1.3 2003/11/17 13:06:24 run2000 Exp $
 * @since 1.8
 */
public class ExtendedIterator extends FastIterator implements TemplateHashModel {

    public ExtendedIterator(List list) {
        super(list);
    }

    /**
     * Gets a {@link TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        if( key.equals( "_isLast" )) {
            return FastBoolean.getInstance(( iterator != null ) && ( ! iterator.hasNext() ));
        }
        return null;
    }
}
