/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.ext.misc;

import org.apache.log4j.Priority;
import org.apache.log4j.Category;
import freemarker.template.*;

/**
 * <p>Adapts FM-Classic's exception events to Log4j's logging methods. This
 * code is known to work with Log4j version 1.1.3, but should be compatible
 * with earlier versions as well.</p>
 *
 * <p>Log4j can be found at the <a href="http://jakarta.apache.org/log4j/"
 * target="_top">Jakarta Apache</a> web site.</p>
 *
 * @author  Nicholas Cull
 * @version $Id: Log4jExceptionListener.java,v 1.6 2003/11/23 00:12:41 run2000 Exp $
 */
public class Log4jExceptionListener implements TemplateExceptionListener {

    private static Priority[] priorities;

    // Note: This assumes the priority constants below never exceed 3.
    static {
        priorities = new Priority[ 4 ];
        priorities[ TemplateRuntimeHandler.SEVERITY_ERROR ] = Priority.ERROR;
        priorities[ TemplateRuntimeHandler.SEVERITY_WARNING ] = Priority.WARN;
        priorities[ TemplateRuntimeHandler.SEVERITY_DEPRECATION ] = Priority.INFO;
    };

    /** Creates new Log4jExceptionListener */
    public Log4jExceptionListener() {
    }

    /**
     * Passes exceptions raised by FreeMarker onto Log4j. The categories
     * supplied to Log4j match the class and method name that caused the
     * event to be fired.
     */
    public void exceptionThrown(TemplateExceptionEvent e) {
        Category cat = Category.getInstance( e.getSourceName() );
        StringBuffer message = new StringBuffer();
        Exception ex = e.getException();

        message.append( ex.getMessage() );
        if( ex instanceof TemplateException ) {
            Exception cause = ((TemplateException)ex).getCauseException();
            if( cause != null ) {
                message.append( ": " );
                message.append( cause.getMessage() );
            }
        }
        cat.log( priorities[ e.getSeverity() ], message.toString() );
    }

}
