/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.template.expression;

/**
 * A null class that represents an open parenthesis. This is for the benefit
 * of {@link ExpressionBuilder}.
 *
 * <p><b>Note:</b><br />
 * <code>OpenParen</code> is a singleton instance. Use the
 * {@link #getInstance()} method to retrieve instances of this model.</p>
 *
 * @version $Id: OpenParen.java,v 1.9 2003/11/27 07:07:12 run2000 Exp $
 */
public final class OpenParen implements Parenthesis {

    /** Singleton instance of this class. */
    private static final OpenParen instance = new OpenParen();

    /**
     * Default constructor.
     *
     * @deprecated use the {@link #getInstance} method to avoid excessive
     * object creation
     */
    public OpenParen() { }

    /**
     * Returns a singleton instance of this class.
     *
     * @return a new OpenParen instance
     */
    public static OpenParen getInstance() {
        return instance;
    }
}
