/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.BinaryData;
import freemarker.template.cache.Cache;
import java.io.BufferedOutputStream;
import java.io.ByteArrayOutputStream;

/**
 * Thread for accessing the cache for a set period of time, then exiting. This
 * is used as part of the {@link TestCacheThreaded} test case.
 *
 * @author  <a href="mailto:run2000@users.sourceforge.net">Nicholas Cull</a>
 * @version $Id: CacheThread4.java,v 1.8 2003/11/28 01:17:06 run2000 Exp $
 * @see CacheThread
 * @see CacheThread2
 * @see CacheThread3
 * @see CacheThread5
 * @see TestCacheThreaded
 */
public final class CacheThread4 implements Runnable {
    private final Cache cCache;
    private final long nPeriod;
    private long nAccesses;

    /** Creates new CacheThread. */
    public CacheThread4(long nPeriod, Cache cCache) {
        this.nPeriod = nPeriod;
        this.cCache = cCache;
        nAccesses = 0;
    }

    /**
     * Run the test for a given period of time.
     */
    public void run() {
        long nTime = System.currentTimeMillis();
        BinaryData cItem;
        int nSize = 0;
        ByteArrayOutputStream cOut;

        while( System.currentTimeMillis() < nTime + nPeriod ) {
            cOut = new ByteArrayOutputStream();
            cItem = (BinaryData)cCache.getItem( "template/test-models.html", "binary" );
            if( cItem == null ) {
                System.out.println( "Null returned." );
            }
            cItem.process( new BufferedOutputStream( cOut ));
            if( nSize != cOut.size() ) {
                nSize = cOut.size();
                System.out.println( "Buffer length (4): " + Integer.toString( nSize ));
            }
            nAccesses++;
        }
        System.out.println( "Number of (4) accesses processed: " + nAccesses );
    }
}
