/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.testcase.models.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/**
 * Test class for testing boolean conditions. In particular, test the
 * {@link freemarker.template.TemplateModel#isEmpty} method implemented by
 * all template models.
 *
 * @version $Id: TestBoolean.java,v 1.10 2003/11/28 01:17:06 run2000 Exp $
 */
public final class TestBoolean extends AbstractTestCase {
    private TemplateModelRoot modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestBoolean( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-boolean.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        modelRoot.put( "boolean1", new BooleanModel1() );
        modelRoot.put( "boolean2", new BooleanModel2() );
        modelRoot.put( "boolean3", new BooleanModel3() );
        modelRoot.put( "boolean4", new BooleanModel4() );
        modelRoot.put( "boolean5", new BooleanModel5() );

        modelRoot.put( "list1", new BooleanList1() );
        modelRoot.put( "list2", new BooleanList2() );

        modelRoot.put( "hash1", new BooleanHash1() );
        modelRoot.put( "hash2", new BooleanHash2() );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringReader( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestBoolean( "test-boolean.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
