/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import java.util.HashMap;
import java.util.Map;

import junit.framework.*;

/**
 * Test class for performing tests on the numeric comparison operations
 * in the <code>freemarker.ext.misc</code> package.
 *
 * @version $Id: TestComparisons.java,v 1.11 2003/11/28 01:17:06 run2000 Exp $
 */
public final class TestComparisons extends AbstractTestCase {
    private TemplateModelRoot modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestComparisons( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-comparisons.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put( "message", new FastScalar( "Hello, world!" ));
        modelRoot.put( "zero", new FastScalar( "0" ));

        // Make the functional model, too.
        Map cMethods = new HashMap();
        cMethods.put( "lessThan", new LessThan() );
        cMethods.put( "lessThanOrEquals", new LessThanOrEquals() );
        cMethods.put( "greaterThan", new GreaterThan() );
        cMethods.put( "greaterThanOrEquals", new GreaterThanOrEquals() );
        cMethods.put( "plus", new Add() );
        cMethods.put( "minus", new Subtract() );
        cMethods.put( "inc", new Increment() );
        cMethods.put( "dec", new Decrement() );

        modelRoot.put( "methods", new FastHash( cMethods ));
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringReader( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestComparisons( "test-comparisons.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
