/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase;

import freemarker.template.*;
import freemarker.ext.misc.AsNumber;
import freemarker.ext.misc.AsString;
import freemarker.testcase.models.*;
import java.io.IOException;
import java.io.StringWriter;
import java.io.StringReader;
import junit.framework.*;

/**
 * Test class for testing Strings and numbers, and the conversions between
 * the two. In particular, test the
 * {@link AsNumber} and {@link AsString} classes in the
 * <code>freemarker.ext.misc</code> package.
 *
 * @version $Id: TestStringNumber.java,v 1.5 2003/11/28 01:17:07 run2000 Exp $
 */
public final class TestStringNumber extends AbstractTestCase {
    private TemplateModelRoot modelRoot;

    /**
     * Constructor that passes the name of the test up to the JUnit
     * constructor.
     *
     * @param aTestname the name of the test
     */
    public TestStringNumber( String aTestname ) {
        super( aTestname );
    }

    /**
     * Set up the test case prior to running.
     */
    public void setUp() {
        setUpFiles( "test-stringnumber.html" );

        // Make a template data model.
        modelRoot = new FastHash();
        modelRoot.put("message", new FastScalar("Hello, world!"));

        modelRoot.put( "number1", new StringNumberModel( "one", 1 ));
        modelRoot.put( "number2", new StringNumberModel( "two", 2 ) );
        modelRoot.put( "number3", new FastScalar ( "3" ));
        modelRoot.put( "string1", new StringNumberModel( "1", 0 ) );
        modelRoot.put( "string2", new StringNumberModel( "2", 1 ) );
        modelRoot.put( "string3", new FastNumber ( 3 ));

        modelRoot.put( "asNumber", AsNumber.getInstance() );
        modelRoot.put( "asString", AsString.getInstance() );
    }

    /**
     * Performs the test. A fail result will generate information about
     * the failure and pass it up to JUnit.
     */
    public void runTest() throws IOException {
        Template cTemplate;
        StringWriter cWriter = new StringWriter();

        cTemplate = new Template( new StringReader( m_aTemplateText ));
        //System.out.println( cTemplate.toString() );

        // Process the template.
        cTemplate.process(modelRoot, cWriter);

        showTestResults( m_aReferenceText, cWriter.toString() );
    }

    /**
     * Bootstrap for the self-test code.
     */
    public static void main( String[] argc ) throws Exception {
        AbstractTestCase cTest = new TestStringNumber( "test-stringnumber.html" );
        TestResult cResults = new TestResult();

        cTest.run( cResults );
    }
}
