/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.beans;

import java.util.List;
import java.util.Map;

/**
 * Simple bean for use with the <code>TestBeanModels</code> test case.
 *
 * @version $Id: SimpleBean.java,v 1.5 2003/11/28 01:17:07 run2000 Exp $
 */
public final class SimpleBean {
    private byte byteValue;
    private int intValue;
    private long longValue;
    private short shortValue;

    private String message;

    private Double doubleObject;
    private Float floatObject;

    /**
     * Default constructor that sets up a bunch of values so that the
     * <code>freemarker.ext.beans</code> package can find them.
     */
    public SimpleBean() {
        byteValue = 127;
        intValue = 5;
        longValue = -10;
        shortValue = 42;
        doubleObject = new Double( 3.14D );
        floatObject = new Float( 3.5F );
        message = "Hello, world!";
    }

    /** Retrieve an integer value from the bean. */
    public int getIntValue() {
        return intValue;
    }

    /** Retrieve a long value from the bean. */
    public long getLongValue() {
        return longValue;
    }

    /** Retrieve a short value from the bean. */
    public short getShortValue() {
        return shortValue;
    }

    /** Retrieve a byte value from the bean. */
    public byte getByteValue() {
        return byteValue;
    }

    /** Sets the bean with a short value. */
    public void setShortValue( short shortValue ) {
        this.shortValue = shortValue;
    }

    /** Retrieve a string value from the bean. */
    public String getMessage() {
        return message;
    }

    /** Retrieve a double object from the bean. */
    public Double getDoubleObject() {
        return doubleObject;
    }

    /** Retrieve a float object from the bean. */
    public Float getFloatObject() {
        return floatObject;
    }

    /** Method call to check for method overloading. */
    public int checkList( List arguments ) {
        return arguments.size();
    }

    /** Method call to check for method overloading. */
    public int checkMap( Map arguments ) {
        return arguments.size();
    }
}
