/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import java.util.ArrayList;
import java.util.List;

import freemarker.template.*;

/**
 * A simple list model for testing the list iterator functionality.
 *
 * @author Nicholas Cull
 * @version $Id: ListModel1.java,v 1.3 2003/11/28 01:17:07 run2000 Exp $
 */
public final class ListModel1 implements TemplateListModel2 {
    private ArrayList items;

    /** Default constructor that creates a simple list. */
    public ListModel1() {
        items = new ArrayList(5);
        items.add( "one" );
        items.add( "two" );
        items.add( "three" );
        items.add( "four" );
        items.add( "five" );
    }

    /**
     * Is the model empty?
     * @return <code>true</code> if the list is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() {
        return items.isEmpty();
    }

    /**
     * Retrieve an iterator to walk through the items in the list.
     *
     * @return a new template iterator to walk through the items with
     */
    public TemplateIteratorModel templateIterator() {
        return new ListIterator1( items );
    }

    /**
     * Return the iterator to the object pool.
     * @param iterator the iterator to be returned
     */
    public void releaseIterator( TemplateIteratorModel iterator ) {
    }

    /**
     * Simple iterator class for testing the iterator model.
     */
    static class ListIterator1 implements TemplateIteratorModel, TemplateHashModel {
        private List items;
        private int currentItem;

        /**
         * Create a new iterator with the given list as the underlying object
         * to walk through.
         * @param items the list of items to iterate over
         */
        public ListIterator1( List items ) {
            this.items = items;
        }

        /**
         * Are there any more elements?
         * @return <code>true</code> if there are more elements, otherwise
         * <code>false</code>
         */
        public boolean hasNext() {
            return currentItem < items.size();
        }

        /**
         * Retrieve the next item in the list.
         * @return the next item in the list
         */
        public TemplateModel next() {
            return new FastScalar( (String)items.get( currentItem++ ));
        }

        /**
         * Is the iterator empty?
         * @return <code>false</code> to indicate the iterator is not empty
         */
        public boolean isEmpty() {
            return false;
        }

        /**
         * Implement special keys that can be retrieved only on the iterator.
         *
         * @param key the name of the item to be retrieved
         * @return a special value, or <code>null</code>
         */
        public TemplateModel get( String key ) {
            if( key.equals( "item" )) {
                return new FastNumber( currentItem );
            } else if( key.equals( "size" )) {
                return new FastNumber( items.size() );
            }
            return null;
        }
    }
}
