/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.*;

import java.util.ArrayList;
import java.util.List;

/**
 * Testcase to see how FM-Classic deals with multiple Template models.
 *
 * @version $Id: MultiModel1.java,v 1.12 2003/11/28 01:17:07 run2000 Exp $
 * @see MultiModel2
 * @see MultiModel3
 * @see MultiModel4
 * @see MultiModel5
 */
public final class MultiModel1 implements TemplateHashModel,
        TemplateListModel2, TemplateIndexedModel, TemplateScalarModel {

    private TemplateModel m_cSubModel = new MultiModel2();
    private TemplateModel m_cListHashModel1 = new MultiModel4();
    private TemplateModel m_cListHashModel2 = new MultiModel5();
    private FastList m_cListModel;
    private TemplateModelRoot m_cHashModel;

    /** Creates new MultiModel1. */
    public MultiModel1() {
        List list = new ArrayList();
        for( int i = 0; i < 10; i++ ) {
            list.add( new FastScalar( "Model1 value: " + Integer.toString( i )));
        }
        list.add( new MultiModel3() );
        m_cListModel = new FastList( list );
        m_cHashModel = new FastHash();
        m_cHashModel.put( "nested", new MultiModel3() );
    }

    /**
     * Gets a {@link freemarker.template.TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        if( key.equals( "model2" )) {
            return m_cSubModel;
        } else if( key.equals( "modellist" )) {
            return m_cListModel;
        } else if( key.equals( "selftest" )) {
            return new FastScalar( "Selftest of a hash from MultiModel1" );
        } else if( key.equals( "one" )) {
            return m_cListHashModel1;
        } else if( key.equals( "two" )) {
            return m_cListHashModel2;
        } else if( key.equals( "size" )) {
            return new FastScalar( "Nasty!" );
        } else if( key.equals( "nesting1" )) {
            return m_cHashModel;
        } else {
            return null;
        }
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Retrieves an iterator to iterate over this list.
     *
     * @return an iterator to iterate over the current list.
     * @throws TemplateModelException the next item in the list can't be
     * retrieved, or no next item exists.
     */
    public TemplateIteratorModel templateIterator() throws TemplateModelException {
        return m_cListModel.templateIterator();
    }

    /**
     * Returns the used iterator to the list model.
     *
     * @param iterator the iterator to be returned to the object pool
     */
    public void releaseIterator(TemplateIteratorModel iterator) {
        m_cListModel.releaseIterator( iterator );
    }

    /**
     * Retrieves the specified item from the list.
     *
     * @param index the index of the item to be retrieved.
     * @return the specified index in the list.
     * @throws TemplateModelException the specified item in the list can't be
     * retrieved, or the index is out of bounds.
     */
    public TemplateModel getAtIndex(long index) throws TemplateModelException {
        return m_cListModel.getAtIndex( index );
    }

    /**
     * Returns the scalar's value as a <code>String</code>.
     *
     * @return the <code>String</code> value of this scalar.
     */
    public String getAsString() throws TemplateModelException {
        return "MultiModel1 as a string!";
    }
}
