/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.*;

/**
 * Testcase to see how FM-Classic deals with multiple Template models.
 *
 * @version $Id: MultiModel3.java,v 1.9 2003/11/28 01:17:07 run2000 Exp $
 * @see MultiModel1
 * @see MultiModel2
 * @see MultiModel4
 * @see MultiModel5
 */
public final class MultiModel3 implements TemplateScalarModel, TemplateHashModel {

    /** Creates new MultiModel3. */
    public MultiModel3() {
    }

    /**
     * Returns the scalar's value as a <code>String</code>.
     *
     * @return the <code>String</code> value of this scalar.
     */
    public String getAsString() throws TemplateModelException {
        return "Model3 is alive!";
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Gets a {@link freemarker.template.TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get(String key) throws TemplateModelException {
        if( key.equals( "selftest" )) {
            return new FastScalar( "Selftest from MultiModel3!" );
        } else if( key.equals( "message" )) {
            return new FastScalar( "Hello world from MultiModel3!" );
        } else {
            return null;
        }
    }

}
