/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */
package freemarker.testcase.models;

import java.util.Map;
import java.util.TreeMap;
import java.util.Collections;

import freemarker.template.*;

/**
 * Simple hash model that contains a sorted hash.
 *
 * @author Nicholas Cull
 * @version $Id: SortedHash.java,v 1.1 2003/11/17 13:21:05 run2000 Exp $
 */
public class SortedHash implements TemplateHashModel, TemplateObjectModel {
    private Map map;

    /**
     * Default constructor that creates a simple sorted map.
     */
    public SortedHash() {
        map = new TreeMap();
        map.put( "test1", new FastScalar( "value1" ));
        map.put( "test2", new FastScalar( "value2" ));
        map.put( "test3", new FastScalar( "value3" ));
    }

    /**
     * Is the object empty?
     *
     * @return <code>true</code> if this object is empty, otherwise <code>false</code>
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }

    /**
     * Gets a {@link TemplateModel} from the hash.
     *
     * @param key the name by which the <code>TemplateModel</code>
     * is identified in the template.
     * @return the <code>TemplateModel</code> referred to by the key,
     * or <code>null</code> if not found.
     */
    public TemplateModel get( String key ) throws TemplateModelException {
        return (TemplateModel)map.get( key );
    }

    /**
     * Return the underlying object to the reflection mechanism in the
     * <code>freemarker.ext.beans</code> package. Any variables, methods
     * or properties can be called directly via reflection.</p>
     *
     * @return the underlying object for this template model
     * @throws TemplateModelException the object could not be returned
     */
    public Object getAsObject() throws TemplateModelException {
        return Collections.unmodifiableMap(map);
    }
}
