/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import freemarker.template.TemplateNumberModel;
import freemarker.template.TemplateScalarModel;
import freemarker.template.TemplateModelException;

/**
 * A simple model that implements both a String and a numeric value. This
 * is used for testing conversions and method models.
 *
 * @author Nicholas Cull
 * @version $Id: StringNumberModel.java,v 1.3 2003/11/28 01:17:07 run2000 Exp $
 */
public final class StringNumberModel implements TemplateScalarModel, TemplateNumberModel {

    private String stringValue;
    private long longValue;

    /**
     * Constructor for initializing both a String and a number value.
     *
     * @param stringValue
     * @param longValue
     */
    public StringNumberModel( String stringValue, long longValue ) {
        this.stringValue = stringValue;
        this.longValue = longValue;
    }

    /**
     * Is the model empty?
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() {
        return false;
    }

    /**
     * Retrieve the scalar value from the model.
     * @return a <code>String</code> value
     */
    public String getAsString() {
        return stringValue;
    }

    /**
     * Retrieve the numeric value from the model.
     *
     * @return a <code>long</code> value
     */
    public long getAsNumber() {
        return longValue;
    }
}
