/*
 * FreeMarker: a tool that allows Java programs to generate HTML
 * output using templates.
 * Copyright (C) 1998-2003 Benjamin Geer
 * Email: beroul@users.sourceforge.net
 *
 * This library is free software; you can redistribute it and/or
 * modify it under the terms of the GNU Library General Public
 * License as published by the Free Software Foundation; either
 * version 2 of the License, or (at your option) any later version.
 *
 * This library is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the GNU
 * Library General Public License for more details.
 *
 * You should have received a copy of the GNU Library General Public
 * License along with this library; if not, write to the
 * Free Software Foundation, Inc., 59 Temple Place - Suite 330,
 * Boston, MA  02111-1307, USA.
 */

package freemarker.testcase.models;

import java.util.*;
import freemarker.template.*;
import freemarker.ext.misc.*;

/**
 * Simple test of the interaction between MethodModels and TransformModels.
 *
 * @author  <a href="mailto:run2000@users.sourceforge.net">Nicholas Cull</a>
 * @version $Id: TransformMethodWrapper1.java,v 1.8 2003/11/08 06:14:42 run2000 Exp $
 * @see TransformMethodWrapper2
 */
public final class TransformMethodWrapper1 implements TemplateMethodModel {

    /** Creates new TransformMethodWrapper1 */
    public TransformMethodWrapper1() {
    }

    /**
     * Executes a method call.
     *
     * @param arguments a <code>List</code> of <code>String</code> objects containing
     * the values of the arguments passed to the method.
     * @return the <code>TemplateModel</code> produced by the method,
     * or <code>null</code>.
     */
    public TemplateModel exec(List arguments) throws TemplateModelException {

        if(( arguments.size() > 0 ) && ( arguments.get( 0 ).toString().equals( "xml" ))) {
            return XmlEscape.getInstance();
        } else {
            return HtmlEscape.getInstance();
        }
    }

    /**
     * Is the model empty?
     *
     * @return <code>false</code> to indicate the model is not empty
     */
    public boolean isEmpty() throws TemplateModelException {
        return false;
    }
}
